@@ -335,29 +335,29 @@ UBX_PAYLOADS_GET = {
         "reserved4": U4,
     },
     "CFG-NAVX5": {
+        "version": U2,
         "mask1": X2,
-        "reserved0": U4,
-        "reserved1": U1,
-        "reserved2": U1,
+        "mask2": X4,
+        "reserved0": U2,
         "minSVs": U1,
         "maxSVs": U1,
         "minCNO": U1,
-        "reserved5": U1,
+        "reserved1": U1,
         "iniFix3D": U1,
-        "reserved6": U1,
-        "reserved7": U1,
-        "reserved8": U1,
+        "reserved2": U2,
+        "ackAiding": U1,
         "wknRollover": U2,
-        "reserved9": U1,
-        "reserved10": U1,
-        "reserved11": U1,
+        "sigAttenCompMode": U1,
+        "reserved3": U1,
+        "reserved4": U2,
+        "reserved5": U2,
         "usePPP": U1,
-        "useAOP": U1,
-        "reserved12": U1,
-        "reserved13": U1,
+        "aopCfg": U1,
+        "reserved6": U2,
         "aopOrbMaxErr": U2,
-        "reserved3": U4,
-        "reserved4": U4,
+        "reserved7": U4,
+        "reserved8": U3,
+        "useAdr": U1,
     },
     "CFG-NMEAvX": {  # deprecated length 4
         "filter": X1,
@@ -1328,19 +1328,25 @@ UBX_PAYLOADS_GET = {
     },
     "NAV-RELPOSNED": {
         "version": U1,
-        "reserved1": U1,
+        "reserved0": U1,
         "refStationID": U2,
         "iTOW": U4,
         "relPosN": I4,
         "relPosE": I4,
         "relPosD": I4,
+        "relPosLength": I4,
+        "relPosHeading": I4,
+        "reserved1": U4,
         "relPosHPN": I1,
         "relPosHPE": I1,
         "relPosHPD": I1,
-        "reserved2": U1,
+        "relPosHPLength": I1,
         "accN": U4,
         "accE": U4,
         "accD": U4,
+        "accLength": U4,
+        "accHeading": U4,
+        "reserved2": U4,
         "flags": X4,
     },
     "NAV-SAT": {
@@ -1365,7 +1371,7 @@ UBX_PAYLOADS_GET = {
     "NAV-SBAS": {
         "iTOW": U4,
         "geo": U1,
-        "mode:": U1,
+        "mode": U1,
         "sys": I1,
         "service": X1,
         "numCh": U1,
